@@ -12,7 +12,7 @@ from typing import Optional
 
 # cli imports
 from mcp_cli.commands.register_commands import register_commands, chat_command
-from mcp_cli.cli_options import process_options
+from mcp_cli.config import process_options
 
 # host imports - this may need updating depending on the new API structure
 # Note: You may need to verify if this import path is still correct in the new APIs
