@@ -27,11 +27,11 @@ class ConversationProcessor:
         self.ui_manager = ui_manager
         self.tool_processor = ToolProcessor(context, ui_manager)
 
-    async def process_conversation(self, max_turns: int = 10):
+    async def process_conversation(self, max_turns: int = 30):
         """Process the conversation loop, handling tool calls and responses with streaming.
 
         Args:
-            max_turns: Maximum number of conversation turns before forcing exit (default: 10)
+            max_turns: Maximum number of conversation turns before forcing exit (default: 30)
         """
         turn_count = 0
         last_tool_signature = None  # Track last tool call to detect duplicates
@@ -149,9 +149,9 @@ class ConversationProcessor:
                         # If this is a duplicate, stop looping and return control to user
                         if (
                             last_tool_signature
-                            and current_sig_str == last_tool_signature  # type: ignore[unreachable]
+                            and current_sig_str == last_tool_signature
                         ):
-                            log.warning(  # type: ignore[unreachable]
+                            log.warning(
                                 f"Duplicate tool call detected: {current_sig_str}"
                             )
                             output.info(
