@@ -30,7 +30,7 @@ from chuk_term.ui import (
     restore_terminal,
 )
 from chuk_term.ui.theme import set_theme
-from mcp_cli.cli_options import process_options
+from mcp_cli.config import process_options
 from mcp_cli.context import initialize_context
 
 # ──────────────────────────────────────────────────────────────────────────────
@@ -92,12 +92,31 @@ def main_callback(
         "--init-timeout",
         help="Server initialization timeout in seconds",
     ),
+    tool_timeout: Optional[float] = typer.Option(
+        None,
+        "--tool-timeout",
+        help="Tool execution timeout in seconds (default: 120, can also set MCP_TOOL_TIMEOUT env var)",
+    ),
+    token_backend: Optional[str] = typer.Option(
+        None,
+        "--token-backend",
+        help="Token storage backend: auto, keychain, windows, secretservice, encrypted, vault",
+    ),
+    max_turns: int = typer.Option(30, "--max-turns", help="Maximum conversation turns"),
 ) -> None:
     """MCP CLI - If no subcommand is given, start chat mode."""
 
     # Re-configure logging based on user options (this overrides the default ERROR level)
     setup_logging(level=log_level, quiet=quiet, verbose=verbose)
 
+    # Store tool timeout if specified
+    if tool_timeout is not None:
+        os.environ["MCP_TOOL_TIMEOUT"] = str(tool_timeout)
+
+    # Store token backend preference if specified
+    if token_backend:
+        os.environ["MCP_CLI_TOKEN_BACKEND"] = token_backend
+
     # Set UI theme and confirmation mode - use preference if not specified
     from mcp_cli.utils.preferences import get_preference_manager
 
@@ -139,10 +158,13 @@ def main_callback(
         from mcp_cli.context import initialize_context
 
         # Initialize context for the provider command
-        initialize_context()
+        initialize_context(token_backend=token_backend)
 
         try:
-            asyncio.run(provider_action_async([provider]))
+            from mcp_cli.commands.models import ProviderActionParams
+
+            params = ProviderActionParams(args=[provider])
+            asyncio.run(provider_action_async(params))
         except Exception as e:
             output.error(f"Error: {e}")
         finally:
@@ -244,7 +266,9 @@ def main_callback(
             logger.debug("Initializing tool manager")
             from mcp_cli.run_command import _init_tool_manager
 
-            tm = await _init_tool_manager(config_file, servers, server_names, init_timeout)
+            tm = await _init_tool_manager(
+                config_file, servers, server_names, init_timeout
+            )
 
             logger.debug("Starting chat mode handler")
             success = await handle_chat_mode(
@@ -253,6 +277,7 @@ def main_callback(
                 model=effective_model,  # Use effective values
                 api_base=api_base,
                 api_key=api_key,
+                max_turns=max_turns,
             )
             logger.debug(f"Chat mode completed with success: {success}")
         except asyncio.TimeoutError:
@@ -262,6 +287,7 @@ def main_callback(
             if tm:
                 logger.debug("Cleaning up after timeout")
                 from mcp_cli.run_command import _safe_close
+
                 await _safe_close(tm)
             raise
         except Exception as e:
@@ -270,12 +296,14 @@ def main_callback(
             if tm:
                 logger.debug("Cleaning up after error")
                 from mcp_cli.run_command import _safe_close
+
                 await _safe_close(tm)
             raise
         finally:
             if tm:
                 logger.debug("Final cleanup of tool manager")
                 from mcp_cli.run_command import _safe_close
+
                 await _safe_close(tm)
 
     try:
@@ -294,6 +322,198 @@ def main_callback(
 # ──────────────────────────────────────────────────────────────────────────────
 # Built-in commands
 # ──────────────────────────────────────────────────────────────────────────────
+
+
+# Chat command - for backward compatibility (same as default behavior)
+@app.command(
+    "chat",
+    help="Start chat mode (default behavior, provided for backward compatibility)",
+)
+def _chat_command(
+    config_file: str = typer.Option(
+        "server_config.json", help="Configuration file path"
+    ),
+    server: Optional[str] = typer.Option(None, help="Server to connect to"),
+    provider: Optional[str] = typer.Option(None, help="LLM provider name"),
+    model: Optional[str] = typer.Option(None, help="Model name"),
+    api_base: Optional[str] = typer.Option(None, "--api-base", help="API base URL"),
+    api_key: Optional[str] = typer.Option(None, "--api-key", help="API key"),
+    disable_filesystem: bool = typer.Option(False, help="Disable filesystem access"),
+    quiet: bool = typer.Option(False, "-q", "--quiet", help="Suppress most log output"),
+    verbose: bool = typer.Option(
+        False, "-v", "--verbose", help="Enable verbose logging"
+    ),
+    log_level: str = typer.Option("WARNING", "--log-level", help="Set log level"),
+    theme: str = typer.Option(
+        "default", "--theme", help="UI theme (default, dark, light, minimal, terminal)"
+    ),
+    confirm_mode: str = typer.Option(
+        None,
+        "--confirm-mode",
+        help="Tool confirmation mode: always, never, or smart (risk-based)",
+    ),
+    init_timeout: float = typer.Option(
+        120.0,
+        "--init-timeout",
+        help="Server initialization timeout in seconds",
+    ),
+) -> None:
+    """Start chat mode (same as default behavior without subcommand)."""
+    # Re-configure logging based on user options
+    setup_logging(level=log_level, quiet=quiet, verbose=verbose)
+
+    # Set confirmation mode if specified
+    if confirm_mode:
+        from mcp_cli.utils.preferences import get_preference_manager
+
+        pref_manager = get_preference_manager()
+        if confirm_mode.lower() in ["always", "never", "smart"]:
+            pref_manager.set_tool_confirmation_mode(confirm_mode.lower())
+        else:
+            output.print(f"[red]Invalid confirmation mode: {confirm_mode}[/red]")
+            output.print("[dim]Valid modes: always, never, smart[/dim]")
+            raise typer.Exit(1)
+
+    # Set UI theme - use preference if not specified
+    from mcp_cli.utils.preferences import get_preference_manager
+
+    pref_manager = get_preference_manager()
+
+    if theme and theme != "default":
+        # User specified theme via command line
+        set_theme(theme)
+        pref_manager.set_theme(theme)  # Save it as preference
+    else:
+        # Use saved preference
+        saved_theme = pref_manager.get_theme()
+        set_theme(saved_theme)
+
+    logger.debug("Starting chat mode (via explicit chat command)")
+
+    # Use ModelManager to get active provider/model if not specified
+    from mcp_cli.model_manager import ModelManager
+
+    model_manager = ModelManager()
+
+    # Handle runtime custom provider if api_base is specified
+    if api_base and provider:
+        # Add as runtime provider (not persisted)
+        logger.debug(f"Adding runtime provider: {provider} with base {api_base}")
+
+        # Parse models if provided in model string (comma-separated)
+        models = None
+        if model and "," in model:
+            models = [m.strip() for m in model.split(",")]
+            model = models[0]  # Use first as default
+
+        model_manager.add_runtime_provider(
+            name=provider,
+            api_base=api_base,
+            api_key=api_key,  # Will be kept in memory only
+            models=models,
+        )
+
+        output.info(f"Using runtime provider: {provider}")
+        if api_key:
+            output.success("API key provided (kept in memory only)")
+        else:
+            import os
+
+            env_var = f"{provider.upper().replace('-', '_')}_API_KEY"
+            if os.environ.get(env_var):
+                output.success(f"Using API key from {env_var}")
+            else:
+                output.warning(f"No API key found. Set {env_var} environment variable.")
+
+    # Validate provider if specified
+    elif provider:
+        if not model_manager.validate_provider(provider):
+            available = ", ".join(model_manager.list_providers())
+            output.error(f"Unknown provider: {provider}")
+            output.info(f"Available providers: {available}")
+            raise typer.Exit(1)
+
+    # Smart provider/model resolution
+    if provider and model:
+        effective_provider = provider
+        effective_model = model
+    elif provider and not model:
+        effective_provider = provider
+        effective_model = model_manager.get_default_model(provider)
+    elif not provider and model:
+        effective_provider = model_manager.get_active_provider()
+        effective_model = model
+    else:
+        effective_provider = model_manager.get_active_provider()
+        effective_model = model_manager.get_active_model()
+
+    servers, _, server_names = process_options(
+        server,
+        disable_filesystem,
+        effective_provider,
+        effective_model,
+        config_file,
+        quiet=quiet,
+    )
+
+    from mcp_cli.chat.chat_handler import handle_chat_mode
+
+    # Start chat mode directly with proper cleanup
+    async def _start_chat():
+        tm = None
+        try:
+            logger.debug("Initializing tool manager")
+            from mcp_cli.run_command import _init_tool_manager
+
+            tm = await _init_tool_manager(
+                config_file, servers, server_names, init_timeout
+            )
+
+            logger.debug("Starting chat mode handler")
+            success = await handle_chat_mode(
+                tool_manager=tm,
+                provider=effective_provider,
+                model=effective_model,
+                api_base=api_base,
+                api_key=api_key,
+            )
+            logger.debug(f"Chat mode completed with success: {success}")
+        except asyncio.TimeoutError:
+            logger.error("Initialization or operation timed out")
+            output.error("Operation timed out. Please check server configuration.")
+            if tm:
+                logger.debug("Cleaning up after timeout")
+                from mcp_cli.run_command import _safe_close
+
+                await _safe_close(tm)
+            raise
+        except Exception as e:
+            logger.error(f"Error in chat mode: {e}")
+            if tm:
+                logger.debug("Cleaning up after error")
+                from mcp_cli.run_command import _safe_close
+
+                await _safe_close(tm)
+            raise
+        finally:
+            if tm:
+                logger.debug("Final cleanup of tool manager")
+                from mcp_cli.run_command import _safe_close
+
+                await _safe_close(tm)
+
+    try:
+        asyncio.run(_start_chat())
+    except KeyboardInterrupt:
+        output.warning("\nInterrupted")
+        logger.debug("Chat mode interrupted by user")
+    except asyncio.TimeoutError:
+        logger.debug("Exiting due to timeout")
+    finally:
+        restore_terminal()
+        raise typer.Exit()
+
+
 @app.command("interactive", help="Start interactive command mode.")
 def _interactive_command(
     config_file: str = typer.Option(
@@ -431,7 +651,7 @@ logger.debug("Registering CLI commands from unified registry")
 # CLICommandAdapter.register_with_typer(app)
 
 # Try unified registry for core commands
-core_commands = ["chat", "cmd", "ping"]
+core_commands = ["cmd", "ping"]
 registry_registered = []
 
 for command_name in core_commands:
@@ -442,7 +662,7 @@ for command_name in core_commands:
         logger.debug(f"Successfully found command in unified registry: {command_name}")
 
 # Direct registration of tool-related commands
-direct_registered = []
+direct_registered = ["chat"]  # Chat is registered directly via @app.command
 
 
 # Shared provider command function
@@ -963,8 +1183,8 @@ def theme_command(
 direct_registered.append("theme")
 
 
-# Token command - manage stored tokens and credentials
-@app.command("token", help="Manage stored tokens and credentials")
+# Token command - manage individual tokens (use 'tokens' to list all)
+@app.command("token", help="Manage individual tokens (use 'tokens' to list)")
 def token_command(
     action: str = typer.Argument(
         ...,
@@ -1035,29 +1255,49 @@ def token_command(
             if not name:
                 output.error("Token name is required for 'set' action")
                 raise typer.Exit(1)
+            from mcp_cli.commands.models import TokenSetParams
+
+            # Use token_type as default namespace if not specified
+            default_namespace = (
+                token_type if token_type in ["bearer", "api-key"] else "generic"
+            )
             return await token_set_action_async(
-                name=name,
-                token_type=token_type,
-                value=value,
-                provider=provider,
-                namespace=namespace or "generic",
+                TokenSetParams(
+                    name=name,
+                    token_type=token_type,
+                    value=value,
+                    provider=provider,
+                    namespace=namespace or default_namespace,
+                )
             )
         elif action == "get":
             if not name:
                 output.error("Token name is required for 'get' action")
                 raise typer.Exit(1)
+            # Use token_type as default namespace if not specified
+            default_namespace = (
+                token_type if token_type in ["bearer", "api-key"] else "generic"
+            )
             return await token_get_action_async(
                 name=name,
-                namespace=namespace or "generic",
+                namespace=namespace or default_namespace,
             )
         elif action == "delete":
             if not name:
                 output.error("Token name is required for 'delete' action")
                 raise typer.Exit(1)
+            from mcp_cli.commands.models import TokenDeleteParams
+
+            # Use token_type as default namespace if not specified
+            default_namespace = (
+                token_type if token_type in ["bearer", "api-key"] else "generic"
+            )
             return await token_delete_action_async(
-                name=name,
-                namespace=namespace,
-                oauth=is_oauth,
+                TokenDeleteParams(
+                    name=name,
+                    namespace=namespace or default_namespace,
+                    oauth=is_oauth,
+                )
             )
         elif action == "clear":
             return await token_clear_action_async(
@@ -1097,6 +1337,297 @@ def token_command(
 
 direct_registered.append("token")
 
+
+# Tokens command - plural form defaults to list (for consistency with providers)
+@app.command("tokens", help="List stored tokens (defaults to list)")
+def tokens_command(
+    action: Optional[str] = typer.Argument(
+        None,
+        help="Action: list, set, get, delete, clear, backends, set-provider, get-provider, delete-provider",
+    ),
+    name: Optional[str] = typer.Argument(
+        None, help="Token/provider name (for set/get/delete actions)"
+    ),
+    token_type: str = typer.Option(
+        "bearer", "--type", "-t", help="Token type (bearer, api-key, generic)"
+    ),
+    value: Optional[str] = typer.Option(None, "--value", help="Token value"),
+    provider: Optional[str] = typer.Option(
+        None, "--provider", "-p", help="Provider name (for API keys)"
+    ),
+    namespace: Optional[str] = typer.Option(
+        None, "--namespace", "-n", help="Storage namespace"
+    ),
+    show_oauth: bool = typer.Option(
+        True, "--show-oauth/--no-oauth", help="Show OAuth tokens (list)"
+    ),
+    show_bearer: bool = typer.Option(
+        True, "--show-bearer/--no-bearer", help="Show bearer tokens (list)"
+    ),
+    show_api_keys: bool = typer.Option(
+        True, "--show-api-keys/--no-api-keys", help="Show API keys (list)"
+    ),
+    show_providers: bool = typer.Option(
+        True, "--show-providers/--no-providers", help="Show provider tokens (list)"
+    ),
+    is_oauth: bool = typer.Option(
+        False, "--is-oauth", help="Delete OAuth token (delete)"
+    ),
+    force: bool = typer.Option(
+        False, "--force", "-f", help="Skip confirmation (clear)"
+    ),
+    quiet: bool = typer.Option(False, "-q", "--quiet", help="Suppress most log output"),
+    verbose: bool = typer.Option(False, "--verbose", help="Enable verbose logging"),
+    log_level: str = typer.Option("WARNING", "--log-level", help="Set log level"),
+) -> None:
+    """List stored tokens (plural form defaults to 'list' action)."""
+    # Configure logging for this command
+    _setup_command_logging(quiet, verbose, log_level, "default")
+
+    from mcp_cli.commands.actions.token import (
+        token_list_action_async,
+        token_set_action_async,
+        token_get_action_async,
+        token_delete_action_async,
+        token_clear_action_async,
+        token_backends_action_async,
+        token_set_provider_action_async,
+        token_get_provider_action_async,
+        token_delete_provider_action_async,
+    )
+    import asyncio
+
+    async def _tokens_wrapper():
+        # Default to 'list' if no action specified (like providers command)
+        effective_action = action or "list"
+
+        if effective_action == "list":
+            from mcp_cli.commands.models import TokenListParams
+            import json
+            from pathlib import Path
+
+            # Load server names from config
+            server_names = []
+            try:
+                config_path = Path("server_config.json")
+                if config_path.exists():
+                    with open(config_path, "r") as f:
+                        config = json.load(f)
+                        server_names = list(config.get("mcpServers", {}).keys())
+            except Exception:
+                pass  # Silently ignore config load errors
+
+            params = TokenListParams(
+                namespace=namespace,
+                show_oauth=show_oauth,
+                show_bearer=show_bearer,
+                show_api_keys=show_api_keys,
+                show_providers=show_providers,
+                server_names=server_names,
+            )
+            return await token_list_action_async(params)
+        elif effective_action == "set":
+            if not name:
+                output.error("Token name is required for 'set' action")
+                raise typer.Exit(1)
+            from mcp_cli.commands.models import TokenSetParams
+
+            params = TokenSetParams(
+                name=name,
+                token_type=token_type,
+                value=value,
+                provider=provider,
+                namespace=namespace or "generic",
+            )
+            return await token_set_action_async(params)
+        elif effective_action == "get":
+            if not name:
+                output.error("Token name is required for 'get' action")
+                raise typer.Exit(1)
+            return await token_get_action_async(
+                name=name,
+                namespace=namespace or "generic",
+            )
+        elif effective_action == "delete":
+            if not name:
+                output.error("Token name is required for 'delete' action")
+                raise typer.Exit(1)
+            from mcp_cli.commands.models import TokenDeleteParams
+
+            params = TokenDeleteParams(
+                name=name,
+                namespace=namespace,
+                oauth=is_oauth,
+            )
+            return await token_delete_action_async(params)
+        elif effective_action == "clear":
+            from mcp_cli.commands.models import TokenClearParams
+
+            params = TokenClearParams(
+                namespace=namespace,
+                force=force,
+            )
+            return await token_clear_action_async(params)
+        elif effective_action == "backends":
+            return await token_backends_action_async()
+        elif effective_action == "set-provider":
+            if not name:
+                output.error("Provider name is required for 'set-provider' action")
+                raise typer.Exit(1)
+            from mcp_cli.commands.models import TokenProviderParams
+
+            params = TokenProviderParams(
+                provider=name,
+                api_key=value,
+            )
+            return await token_set_provider_action_async(params)
+        elif effective_action == "get-provider":
+            if not name:
+                output.error("Provider name is required for 'get-provider' action")
+                raise typer.Exit(1)
+            from mcp_cli.commands.models import TokenProviderParams
+
+            params = TokenProviderParams(provider=name)
+            return await token_get_provider_action_async(params)
+        elif effective_action == "delete-provider":
+            if not name:
+                output.error("Provider name is required for 'delete-provider' action")
+                raise typer.Exit(1)
+            from mcp_cli.commands.models import TokenProviderParams
+
+            params = TokenProviderParams(provider=name)
+            return await token_delete_provider_action_async(params)
+        else:
+            output.error(f"Unknown action: {effective_action}")
+            output.hint(
+                "Valid actions: list, set, get, delete, clear, backends, set-provider, get-provider, delete-provider"
+            )
+            raise typer.Exit(1)
+
+    # Run the async function
+    asyncio.run(_tokens_wrapper())
+
+
+direct_registered.append("tokens")
+
+
+# Cmd command - Unix-friendly automation mode
+@app.command("cmd", help="Command mode for Unix-friendly automation and scripting")
+def cmd_command(
+    input_file: Optional[str] = typer.Option(
+        None, "--input", "-i", help="Input file (use - for stdin)"
+    ),
+    output_file: Optional[str] = typer.Option(
+        None, "--output", "-o", help="Output file (use - for stdout)"
+    ),
+    prompt: Optional[str] = typer.Option(None, "--prompt", "-p", help="Prompt text"),
+    tool: Optional[str] = typer.Option(
+        None, "--tool", "-t", help="Tool name to execute"
+    ),
+    tool_args: Optional[str] = typer.Option(
+        None, "--tool-args", help="Tool arguments as JSON"
+    ),
+    system_prompt: Optional[str] = typer.Option(
+        None, "--system-prompt", help="Custom system prompt"
+    ),
+    raw: bool = typer.Option(False, "--raw", help="Raw output without formatting"),
+    single_turn: bool = typer.Option(
+        False, "--single-turn", help="Disable multi-turn conversation"
+    ),
+    max_turns: int = typer.Option(30, "--max-turns", help="Maximum conversation turns"),
+    config_file: str = typer.Option(
+        "server_config.json", help="Configuration file path"
+    ),
+    server: Optional[str] = typer.Option(None, help="Server to connect to"),
+    provider: Optional[str] = typer.Option(None, help="LLM provider name"),
+    model: Optional[str] = typer.Option(None, help="Model name"),
+    api_base: Optional[str] = typer.Option(None, "--api-base", help="API base URL"),
+    api_key: Optional[str] = typer.Option(None, "--api-key", help="API key"),
+    disable_filesystem: bool = typer.Option(False, help="Disable filesystem access"),
+    quiet: bool = typer.Option(False, "-q", "--quiet", help="Suppress most log output"),
+    verbose: bool = typer.Option(False, "--verbose", help="Enable verbose logging"),
+    log_level: str = typer.Option("WARNING", "--log-level", help="Set log level"),
+    theme: str = typer.Option("default", "--theme", help="UI theme"),
+    init_timeout: float = typer.Option(
+        120.0, "--init-timeout", help="Server initialization timeout in seconds"
+    ),
+) -> None:
+    """Command mode for Unix-friendly automation and scripting."""
+    # Configure logging and theme
+    _setup_command_logging(quiet, verbose, log_level, theme)
+
+    # Use ModelManager to resolve provider/model
+    from mcp_cli.model_manager import ModelManager
+
+    model_manager = ModelManager()
+
+    # Smart provider/model resolution
+    if provider and model:
+        effective_provider = provider
+        effective_model = model
+    elif provider and not model:
+        effective_provider = provider
+        effective_model = model_manager.get_default_model(provider)
+    elif not provider and model:
+        effective_provider = model_manager.get_active_provider()
+        effective_model = model
+    else:
+        effective_provider = model_manager.get_active_provider()
+        effective_model = model_manager.get_active_model()
+
+    # Process server options
+    servers, _, server_names = process_options(
+        server,
+        disable_filesystem,
+        effective_provider,
+        effective_model,
+        config_file,
+        quiet=quiet,
+    )
+
+    # Import cmd action
+    from mcp_cli.commands.actions.cmd import cmd_action_async
+
+    # Execute via run_command_sync
+    async def _cmd_wrapper(**params):
+        return await cmd_action_async(
+            input_file=params.get("input_file"),
+            output_file=params.get("output_file"),
+            prompt=params.get("prompt"),
+            tool=params.get("tool"),
+            tool_args=params.get("tool_args"),
+            system_prompt=params.get("system_prompt"),
+            raw=params.get("raw", False),
+            single_turn=params.get("single_turn", False),
+            max_turns=params.get("max_turns", 30),
+        )
+
+    run_command_sync(
+        _cmd_wrapper,
+        config_file,
+        servers,
+        extra_params={
+            "input_file": input_file,
+            "output_file": output_file,
+            "prompt": prompt,
+            "tool": tool,
+            "tool_args": tool_args,
+            "system_prompt": system_prompt,
+            "raw": raw,
+            "single_turn": single_turn,
+            "max_turns": max_turns,
+            "server_names": server_names,
+            "provider": effective_provider,
+            "model": effective_model,
+            "api_base": api_base,
+            "api_key": api_key,
+            "init_timeout": init_timeout,
+        },
+    )
+
+
+direct_registered.append("cmd")
+
 # Show what we actually registered
 all_registered = registry_registered + direct_registered
 output.success("✓ MCP CLI ready")
