@@ -469,10 +469,10 @@ class ModelManager:
 
         try:
             from mcp_cli.auth.provider_tokens import get_provider_token_with_hierarchy
-            from mcp_cli.auth.token_manager import TokenManager
+            from mcp_cli.auth import TokenManager
 
             # Get token manager
-            token_manager = TokenManager()
+            token_manager = TokenManager(service_name="mcp-cli")
 
             # Check hierarchically (env vars > storage)
             api_key, source = get_provider_token_with_hierarchy(
@@ -500,9 +500,9 @@ class ModelManager:
 
         try:
             from mcp_cli.auth.provider_tokens import get_provider_token_with_hierarchy
-            from mcp_cli.auth.token_manager import TokenManager
+            from mcp_cli.auth import TokenManager
 
-            token_manager = TokenManager()
+            token_manager = TokenManager(service_name="mcp-cli")
             _, source = get_provider_token_with_hierarchy(provider_name, token_manager)
             return source
 
@@ -687,7 +687,7 @@ class ModelManager:
 
         try:
             from mcp_cli.auth.provider_tokens import get_provider_token_with_hierarchy
-            from mcp_cli.auth.token_manager import TokenManager
+            from mcp_cli.auth import TokenManager
             import os
 
             # Check if env var is already set (highest priority)
@@ -700,7 +700,7 @@ class ModelManager:
                 return
 
             # Get token from storage
-            token_manager = TokenManager()
+            token_manager = TokenManager(service_name="mcp-cli")
             api_key, source = get_provider_token_with_hierarchy(
                 provider_name, token_manager
             )
@@ -726,7 +726,7 @@ class ModelManager:
 
         # Use hierarchical token resolution for custom providers too
         from mcp_cli.auth.provider_tokens import get_provider_token_with_hierarchy
-        from mcp_cli.auth.token_manager import TokenManager
+        from mcp_cli.auth import TokenManager
 
         # Check runtime keys first
         api_key = self._runtime_api_keys.get(provider)
@@ -734,7 +734,7 @@ class ModelManager:
         if not api_key:
             # Use hierarchical resolution (env vars > storage)
             try:
-                token_manager = TokenManager()
+                token_manager = TokenManager(service_name="mcp-cli")
                 api_key, source = get_provider_token_with_hierarchy(
                     provider, token_manager
                 )
@@ -861,7 +861,7 @@ class ModelManager:
     def get_discovery_status(self) -> Dict[str, Any]:
         """Get discovery status information"""
         try:
-            from mcp_cli.cli_options import get_discovery_status
+            from mcp_cli.config import get_discovery_status
 
             return get_discovery_status()
         except Exception:
